==> plugin-api-1.2.2-sources.jar: com/xebialabs/deployit/steps/DeleteStep.java <==
/*
 * Copyright (c) 2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to  (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.steps;

import com.xebialabs.deployit.StepExecutionContext;
import com.xebialabs.deployit.ci.Host;
import com.xebialabs.deployit.hostsession.HostFile;
import com.xebialabs.deployit.hostsession.HostSession;

/**
 * Steps that deletes a file or a directory on a host.
 */
@SuppressWarnings("serial")
public class DeleteStep extends HostSessionStep {

	private String locationToDelete;

	private String exclusionPattern;

	/**
	 * Creates a <tt>DeleteStep</tt> that deletes a file/directory on a remote host. Directories are deleted
	 * recursively.
	 * 
	 * @param host
	 *            the host
	 * @param pathToDelete
	 *            the file or directory to delete.
	 */
	public DeleteStep(Host host, String pathToDelete) {
		super(host);
		setDescription("Delete " + pathToDelete + " from " + host.getAddress());
		this.locationToDelete = pathToDelete;
		this.exclusionPattern = null;
	}

	/**
	 * Creates a <tt>DeleteStep</tt> that delete a file/directory on a remote host. Directories are deleted recursively.
	 * 
	 * @param host
	 *            the host
	 * @param pathToDelete
	 *            the file or directory to delete.
	 * @param exclusionPattern
	 *            a pattern of files that should not be removed when doing a recursive directory deletion. See
	 *            {@link HostFile#deleteRecursively(String)} for the specification of the pattern.
	 */
	public DeleteStep(Host host, String pathToDelete, String exclusionPattern) {
		super(host);
		setDescription("Delete " + pathToDelete + " from " + host.getAddress());
		this.locationToDelete = pathToDelete;
		this.exclusionPattern = exclusionPattern;
	}

	public boolean execute(StepExecutionContext ctx) {
		HostSession session = getHostSession();
		try {
			ctx.logOutput("Deleting " + locationToDelete);
			HostFile fileToDelete = session.getFile(locationToDelete);
			if (exclusionPattern != null) {
				return fileToDelete.deleteRecursively(exclusionPattern);
			} else {
				return fileToDelete.deleteRecursively();
			}
		} finally {
			session.close();
		}
	}

}

==> plugin-api-1.3.2.1-sources.jar: com/xebialabs/deployit/steps/DeleteStep.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.steps;

import com.xebialabs.deployit.StepExecutionContext;
import com.xebialabs.deployit.ci.Host;
import com.xebialabs.deployit.hostsession.HostFile;
import com.xebialabs.deployit.hostsession.HostSession;

/**
 * Steps that deletes a file or a directory on a host.
 */
@SuppressWarnings("serial")
public class DeleteStep extends HostSessionStep {

	private String locationToDelete;

	/**
	 * Creates a <tt>DeleteStep</tt> that deletes a file/directory on a remote host. Directories are deleted
	 * recursively.
	 * 
	 * @param host
	 *            the host
	 * @param pathToDelete
	 *            the file or directory to delete.
	 */
	public DeleteStep(Host host, String pathToDelete) {
		super(host);
		setDescription("Delete " + pathToDelete + " from " + host.getAddress());
		this.locationToDelete = pathToDelete;
	}

	/**
	 * @deprecated the exclusionPattern is not used, so use the other constructor
	 */
	public DeleteStep(Host host, String pathToDelete, String exclusionPattern) {
		this(host, pathToDelete);
	}

	public boolean execute(StepExecutionContext ctx) {
		HostSession session = getHostSession();
		try {
			ctx.logOutput("Deleting " + locationToDelete);
			HostFile fileToDelete = session.getFile(locationToDelete);
			if(fileToDelete.exists()){
				ctx.logOutput("Deleting " + locationToDelete);
				return fileToDelete.deleteRecursively();
			}else{
				ctx.logOutput("Deleting  " + locationToDelete + ": file no longer exists");
				return true;
			}
		} finally {
			session.close();
		}
	}

}
